Installation instructions — HavNegpy 1.1 documentation

# Installation instructions

## Dependencies

`HavNegpy` requires the use of numpy scipy matplotlib mplcursors

## Installation

`HavNegpy` is currently available on PyPI and can be installed using the standard pip command:

    pip install HavNegpy

Alternatively it can be installed by downloading the source code or cloning the GitHub repository and running the standard:

    python setup.py install

command or its usual variants (`python setup.py install --user`, `python setup.py install --prefix=/PATH/TO/INSTALL/DIRECTORY`, etc.).

For more info, please open an Issue on the GitHub page.